// Author: Lech Duraj

#include <cstdio>
#include <cstdlib>
#include <cmath>
#include <cassert>
#include <algorithm>
#include <vector>

using namespace std;

typedef long long LL;

typedef pair<LL,LL> PLL;

vector<PLL> pyth;

const int maxn = 2000;
const int maxr = 10000;

LL X[maxn],Y[maxn],R[maxn];


LL rad2(PLL a)
{
    return a.first*a.first+a.second*a.second;
}

LL rad(PLL a)
{
    LL r2 = rad2(a);
    LL r = round(sqrtl(rad2(a)));
    assert(r*r==r2);
    return r;
}

bool cmp(PLL a, PLL b)
{
    return rad2(a)<rad2(b);
}

void precompute(LL range)
{
    for(LL i=1; i<range; i++)
        for(LL j=i+1; i*i+j*j<range; j++)
        {
            LL p = j*j-i*i;
            LL q = 2*i*j;
            for(int a = 0; a <= 1; a++)
            {
                pyth.push_back(PLL(p,q));
                pyth.push_back(PLL(p,-q));
                pyth.push_back(PLL(-p,q));
                pyth.push_back(PLL(-p,-q));
                swap(p,q);
            }
        }
    sort(pyth.begin(),pyth.end(),cmp);
}

LL sq(LL x)
{
    return x*x;
}

bool overlap(int i, int j)
{
    return sq(X[i]-X[j])+sq(Y[i]-Y[j])<=sq(R[i]+R[j]);
}

void gen_growing(int n, LL range, int starter, bool stay = false)
{
    fprintf(stderr,"Generating...\n");
    int r = 0;
    while(r<=pyth.size() && rad2(pyth[r])<range*range)
        r++;
    int m = 1;
    X[0] = 0;
    Y[0] = 0;
    R[0] = starter;
    printf("%d\n",n);
    while(m<n)
    {
        int i = lrand48()%m;
        int s = lrand48()%r;
        if (rad2(pyth[s])<=R[i]*R[i])
            continue;
        X[m] = X[i]+pyth[s].first;
        Y[m] = Y[i]+pyth[s].second;
        R[m] = rad(pyth[s])-R[i];
        if (abs(X[m])>range || abs(Y[m])>range)
            continue;
        if ((m>n/2) &&(R[m]>1) && (lrand48()%40==0))
            R[m]--;
        bool ok = true;
        for(int j=0; j<m; j++)
            ok &= (j==i) || (!overlap(j,m));
        if (ok)
            m++;
    }
    vector<int> A;
    for(int i=0; i<n; i++)
        A.push_back(i);
    if (stay)
        random_shuffle(A.begin()+1,A.end());
    else
        random_shuffle(A.begin(),A.end());
    for(int i=0; i<n; i++)
        printf("%Ld %Ld %Ld\n",X[A[i]],Y[A[i]],R[A[i]]);
    fprintf(stderr,"Done.\n");
}

void gen_snowman(int n)
{
    vector<int> P;
    P.push_back(1);
    printf("%d\n",n);
    printf("0 0 1\n");
    int last = 0;
    int k = 2;
    for(int i=1; i<=n-1; i++)
    {
        bool ok = true;
        do
        {
            ok = true;
            for(int j=1; j<P.size() && P[j]*P[j]<=k; j++)
                ok &= (k % P[j] != 0);
            if (ok)
                P.push_back(k);
            k++;
        }
        while(!ok);
        printf("%d %d %d\n",0,last-P[i-1]-P[i],P[i]);
        last = last-P[i-1]-P[i];
    }
}

void gen_necklace(int n)
{
    const int r1 = 7;
    const int r2 = 5;
    const int R = 13;
    printf("%d\n",n);
    int s = (int)sqrt(n)+1;
    if (s%2!=0)
        s++;
    for(int i=0; i<n; i++)
    {
        int y = i/s;
        int x = i%s;
        if (x==(s-1))
            printf("%d %d %d\n",(y%2==0) ? (s-2)*(r1+r2) : 0, y*(2*r1+2*R)+r1+R, R);
        else
            printf("%d %d %d\n",x*(r1+r2),y*(2*r1+2*R),(x%2==0) ? r1 : r2);
    }
}

void gen_cycle(int n)
{
    int x = 0;
    printf("%d\n",4*n+2);
    for(int i=n; i>=1; i--)
    {
        printf("%d %d %d\n",x,0,i);
        printf("%d %d %d\n",x,4*n,i);
        x += i+(i-1);
    }
    x += 1;
    for(int i=1; i<=n; i++)
    {
        printf("%d %d %d\n",x,0,i);
        printf("%d %d %d\n",x,4*n,i);
        x += i+(i+1);
    }
    x -= n+(n+1);
    printf("%d %d %d\n",0,2*n,n);
    printf("%d %d %d\n",x,2*n,n);    
}

void gen_mattress(int x, int y)
{
    const int R = 17;
    const int r = 11;
    printf("%d\n",x*y);
    for(int i=0; i<x; i++)
        for(int j=0; j<y; j++)
            printf("%d %d %d\n",(R+r)*i,(R+r)*j,(i+j)%2 ? R : r);
}


int main()
{
    srand48(6112);
    printf("%d\n",61);
    precompute(maxr);
    gen_snowman(5);     // 0
    for(int t=1; t<27; t++)
        gen_growing(10+lrand48()%10,100,lrand48()%20+1);
    gen_snowman(50);    // 27
    gen_necklace(100);  // 28
    gen_mattress(9,13); // 39
    gen_cycle(67);      // 30
    for(int t=31; t<50; t++)
        gen_growing(50+lrand48()%50,300,t%2 ? 120 : 100+lrand48()%100,true);
    for(int t=50; t<57; t++)
    {
        fprintf(stderr,"%d.\n",t);
        gen_growing(600+lrand48()%400,2000,100+lrand48()%100,t%2);
    }
    gen_necklace(1000);                 // 57
    gen_growing(1000,10000,840,true);   // 58
    gen_growing(1000,10000,1000,false); // 59
    gen_mattress(31,32);                // 61
}
